@@ -12,4 +12,8 @@ def main():
     cli.add_command(list_group)
     cli.add_command(convert)
     cli.add_command(check)
-    cli()
\ No newline at end of file
+    cli()
+
+
+if __name__ == "__main__":
+    main()
